//
// Author: 
//   Mikael Hallendal <micke@imendio.com>
//
// (C) 2004 Imendio HB
// 

using Gdk;
using Gtk;
using Glade;
using System;
using System.Text;

namespace Imendio.Blam {
    public class ChannelDialog {
	[Widget] Gtk.Dialog channelDialog;
	[Widget] Gtk.Entry  nameEntry;
	[Widget] Gtk.Entry  urlEntry;
	[Widget] Gtk.Entry  imageEntry;
	[Widget] Gtk.Button okButton;
	[Widget] Gtk.Image  dialogImage;

	private Channel     mChannel;
	
	private Application mApp;

	private static Gtk.FileSelection fileDialog = null;

	public string Name {
	    get {
		return nameEntry.Text;
	    }
	    set {
		nameEntry.Text = value;
	    }
	}
	
	public string Url {
	    get {
		return urlEntry.Text;
	    }
	    set {
		urlEntry.Text = value;
	    }
	}
	
	public string Image {
	    get {
		return imageEntry.Text;
	    }
	    set {
		imageEntry.Text = value;
	    }
	}

	public ChannelDialog (Application app)
	{
	    mApp = app;
	    
	    Glade.XML gladeXML = Glade.XML.FromAssembly("blam.glade",
							"channelDialog",
							null);
	    gladeXML.Autoconnect(this);
	    channelDialog.TransientFor = mApp.Window;
	    channelDialog.Icon = Gdk.Pixbuf.LoadFromResource("blam.png");
	    
	    dialogImage.Pixbuf = 
		Gdk.Pixbuf.LoadFromResource ("blam-edit-news.png");
	    
	    Gtk.Drag.DestSet(channelDialog, DestDefaults.All, 
			     Application.DragEntries, 
			     DragAction.Copy | DragAction.Move);
	   
	    channelDialog.DragDataReceived += DragDataReceivedCb;
	}

	public void Show (Channel channel)
	{
	    mChannel = channel;
	    
	    nameEntry.Text = channel.Name;
	    urlEntry.Text = channel.Url;
	    imageEntry.Text = channel.Image;
	    
	    channelDialog.ShowAll ();
	}
	
	private void CancelButtonClicked (object obj, EventArgs args)
	{
	    channelDialog.Hide();
	}

	private void OkButtonClicked (object obj, EventArgs args)
	{
	    mChannel.Name = nameEntry.Text;
	    mChannel.Url = urlEntry.Text;
	    mChannel.Image = imageEntry.Text;

	    mApp.CCollection.Update (mChannel);

	    channelDialog.Hide ();
	}

	private void EntryChanged (object obj, EventArgs args)
	{
	    if (!nameEntry.Text.Equals("") && !urlEntry.Text.Equals("")) {
		okButton.Sensitive = true;
	    } else {
		okButton.Sensitive = false;
	    }
	}

	private void EntryActivated (object obj, EventArgs args)
	{
	    if (!nameEntry.Text.Equals("") && !urlEntry.Text.Equals("")) {
		okButton.Click();
	    }
	}

	private void ImageButtonClicked(object obj, EventArgs args)
	{
	    if (fileDialog == null) {
		fileDialog = new Gtk.FileSelection("Chose an image");
		fileDialog.Modal = true;
		fileDialog.ShowFileops = false;
	    }

	    if (mChannel == null || mChannel.Image == null) {
		// Go to some place
		Console.WriteLine("No image");
	    } else {
		fileDialog.Filename = mChannel.Image;
	    }
	    
	    fileDialog.TransientFor = this.channelDialog;
	    int result = fileDialog.Run();
	    
	    switch (result) {
	    case (int)ResponseType.Ok: 
		imageEntry.Text = fileDialog.Filename;
		break;
	    }

	    fileDialog.Hide();
	}
    
	private void DragDataReceivedCb(object o, DragDataReceivedArgs args)
	{
	    SelectionData d = args.SelectionData;
	    
	    if (d.Length < 0 && d.Format != 8){
		Gtk.Drag.Finish(args.Context, false, false, args.Time);
		return;
	    }

	    UTF8Encoding encoding = new UTF8Encoding( );
	    string text = encoding.GetString(d.Data);
	   
	    Image = text;
	    
	    Gtk.Drag.Finish(args.Context, true, true, args.Time);
	}
    }
}
